IF OBJECT_ID('[Packages_Combined]') IS NOT NULL DROP VIEW [Packages_Combined]
GO

CREATE VIEW [Packages_Combined]
AS
	SELECT * FROM
	(SELECT P.[Feed_Id],
	        F.[Feed_Name],
			P.[Package_Id],
			V.[Version_Text],
			V.[Published_Date],
			F.[FeedType_Name],
            V.[Download_Count],
            [Group_Id] = NULL,
			V.[Cached_Indicator]
	  FROM [NuGetPackageVersionsV2] V
	       INNER JOIN [NuGetPackagesV2] P
		           ON P.[NuGetPackageV2_Id] = V.[NuGetPackageV2_Id]
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = P.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y') A

	UNION ALL
	SELECT * FROM

	(SELECT NP.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = CASE WHEN NP.[Scope_Name] = '' THEN NP.[Package_Name] ELSE '@' + NP.[Scope_Name] + '/' + NP.[Package_Name] END,
			NPV.[Version_Text],
			NPV.[Published_Date],
			F.[FeedType_Name],
            NPV.[Download_Count],
            [Group_Id] = NULL,
			NPV.[Cached_Indicator]
		  FROM [NpmPackageVersions] NPV
		       INNER JOIN [NpmPackages] NP
			           ON NP.[Package_Id] = NPV.[Package_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = NP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y') B


	UNION ALL
	SELECT * FROM

	(SELECT MA.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = MA.[ArtifactId_Text],
			MAF.[Version_Text],
			MAF.[Updated_Date],
			F.[FeedType_Name],
            MAF.[Download_Count],
            [Group_Id] = MA.[GroupId_Text],
			MAF.[Cached_Indicator]
		  FROM [MavenArtifacts] MA
		       INNER JOIN [MavenArtifactFiles] MAF
			           ON MAF.[MavenArtifact_Id] = MA.[MavenArtifact_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = MA.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND MAF.[File_Type] = '.pom') C

	UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = PGP.[Package_Name],
			PGPV.[Version_Text],
			PGPV.[Published_Date],
			F.[FeedType_Name],
            PGP.[Download_Count],
            [Group_Id] = PGP.[Group_Name],
			PGPV.[Cached_Indicator]
		  FROM [ProGetPackageVersions] PGPV
		       INNER JOIN [ProGetPackages] PGP
			           ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = PGP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y') D

	UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = DP.[Package_Name] + '/' + DP.[Architecture_Name],
			DP.[Version_Text],
			DP.[Published_Date],
			F.[FeedType_Name],
            DP.[Download_Count],
            [Group_Id] = DP.[Component_Name],
			DP.[Cached_Indicator]
		  FROM [DebianPackages] DP
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = DP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y') E

	UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
	        [Package_Id] = HC.[Chart_Name],
	        HC.[Version_Text],
	        HC.[Published_Date],
	        F.[FeedType_Name],
	        HC.[Download_Count],
	        [Group_Id] = NULL,
			HC.[Cached_Indicator]
	      FROM [HelmCharts] HC
	           INNER JOIN [Feeds] F
	                   ON F.[Feed_Id] = HC.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y') F


	UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
	        [Package_Id] = Py.[Package_Name],
	        Py.[Version_Text],
	        Py.[Published_Date],
	        F.[FeedType_Name],
	        Py.[Download_Count],
	        [Group_Id] = NULL,
			Py.[Cached_Indicator]
	      FROM [PypiPackages] Py
	           INNER JOIN [Feeds] F
	                   ON F.[Feed_Id] = Py.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y') G

   	UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = RP.[Package_Name] COLLATE Latin1_General_CS_AS,
			[Version_Text] = RPV.[FullVersion_Text],
			RPV.[Published_Date],
			F.[FeedType_Name],
            RPV.[Download_Count],
            [Group_Id] = RP.[Architecture_Name] COLLATE Latin1_General_CS_AS,
			[Cached_Indicator] = 'N'
		  FROM [RpmPackageVersions] RPV
		       INNER JOIN [RpmPackages] RP
			           ON RP.[RpmPackage_Id] = RPV.[RpmPackage_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = RP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y') H

GO