EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Assets_GetItemFromPath',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'AssetItems(1),AssetItemMetadata',
    /* OutputPropertyNames_Csv */ 'CanonicalAssetPath_Text,CacheConfiguration_XML',
    /* Description_Text        */ 'Returns the item with the specified full path and its user-defined metadata if it was found.',
	/* Remarks_Text            */ 'Path must use forward slash (/) and not have any leading or trailing slashes. Paths are case-sensitive unless AllowCaseInsensitiveMatch_Indicator is Y.'
GO

IF OBJECT_ID('[Assets_GetItemFromPath]') IS NOT NULL DROP PROCEDURE [Assets_GetItemFromPath]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Assets_GetItemFromPath]
(
	@Feed_Id INT,
	@AssetPath_Text NVARCHAR(MAX),
	@IncludeDeleted_Indicator YNINDICATOR,
	@AllowCaseInsensitiveMatch_Indicator YNINDICATOR,
	@CanonicalAssetPath_Text NVARCHAR(MAX) = NULL OUT,
	@CacheConfiguration_XML XML = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON


	SELECT AP.* INTO #AssetPath
	  FROM [AssetItems] A INNER JOIN [AssetItems_Paths] AP ON A.[AssetItem_Id] = AP.[AssetItem_Id]
	 WHERE A.[Feed_Id] = @Feed_Id
	   AND (@IncludeDeleted_Indicator = 'Y' OR A.[Deleted_Date] IS NULL)
	   AND (   (@AllowCaseInsensitiveMatch_Indicator = 'Y' AND AP.[AssetItem_Lower_Path] = LOWER(@AssetPath_Text))
	        OR (@AllowCaseInsensitiveMatch_Indicator = 'N' AND AP.[AssetItem_Path] = @AssetPath_Text) )

	-- return item if it was found
	SELECT * 
	  FROM [AssetItems] 
	 WHERE [AssetItem_Id] = (SELECT [AssetItem_Id] FROM #AssetPath)

	SELECT *
	  FROM [AssetItemMetadata]
	 WHERE [AssetItem_Id] = (SELECT [AssetItem_Id] FROM #AssetPath)

	 SELECT @CanonicalAssetPath_Text = [AssetItem_Path],
            @CacheConfiguration_XML = [Inhereted_CacheConfiguration_Xml]
	   FROM #AssetPath

END
GO

GRANT EXECUTE ON [Assets_GetItemFromPath] TO [ProGetUser_Role]