EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Assets_GetItems',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'AssetItems',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Returns all of the items in an asset directory folder, or in the asset directory root.',
	/* Remarks_Text            */ 'When Parent_AssetItem_Id is null, the top-level pseudo-folder of the asset directory is referenced.'
GO

IF OBJECT_ID('[Assets_GetItems]') IS NOT NULL DROP PROCEDURE [Assets_GetItems]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Assets_GetItems]
(
	@Feed_Id INT,
	@Parent_AssetItem_Id INT = NULL,
	@Recursive_Indicator YNINDICATOR = 'N',
	@IncludeDeleted_Indicator YNINDICATOR = 'N'
)
AS
BEGIN

	SET NOCOUNT ON

	IF @Parent_AssetItem_Id IS NULL BEGIN

		SELECT *
		  FROM [AssetItems]
		 WHERE [Feed_Id] = @Feed_Id
		   AND (@Recursive_Indicator = 'Y' OR [Parent_AssetItem_Id] IS NULL)
		   AND (@IncludeDeleted_Indicator = 'Y' OR [Deleted_Date] IS NULL)

	END ELSE IF @Recursive_Indicator = 'Y' BEGIN

		;WITH AI_CTE AS (
			SELECT *
			  FROM [AssetItems]
			 WHERE [Parent_AssetItem_Id] = @Parent_AssetItem_Id
			UNION ALL
			SELECT AI.*
			  FROM [AssetItems] AI
			       INNER JOIN AI_CTE AI2
				           ON AI2.[AssetItem_Id] = AI.[Parent_AssetItem_Id]
		)
		SELECT *
		  FROM AI_CTE
		 WHERE [Feed_Id] = @Feed_Id
		   AND (@IncludeDeleted_Indicator = 'Y' OR [Deleted_Date] IS NULL);

	END ELSE BEGIN

		SELECT *
		  FROM [AssetItems]
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Parent_AssetItem_Id] = @Parent_AssetItem_Id
		   AND (@IncludeDeleted_Indicator = 'Y' OR [Deleted_Date] IS NULL)

	END

END
GO

GRANT EXECUTE ON [Assets_GetItems] TO [ProGetUser_Role]