EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Assets_SearchItems',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'AssetItems_Paths',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Searches the items in an asset directory based on a search string.',
	/* Remarks_Text            */ NULL
GO

IF OBJECT_ID('[Assets_SearchItems]') IS NOT NULL DROP PROCEDURE [Assets_SearchItems]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Assets_SearchItems]
(
	@Feed_Id INT,
	@Search_Text NVARCHAR(200),
	@BasePath_Text NVARCHAR(MAX) = NULL,
	@IncludeDeleted_Indicator YNINDICATOR = 'N'
)
AS
BEGIN

	SET @Search_Text = LOWER(@Search_Text)

	SELECT [AssetItem_Id], 
	       [Word_Count] = COUNT(*), 
	       [Name_Index] = MIN(NULLIF(CHARINDEX(WORD.[Value_Text] COLLATE Latin1_General_CS_AS, [AssetItem_Lower_Name]),0))
      INTO #Results
	  FROM [AssetItems_Paths] AI
	       CROSS JOIN dbo.CsvToTable(@Search_Text, ' ') WORD
	 WHERE NULLIF(RTRIM(LTRIM(WORD.[Value_Text])), '') IS NOT NULL
	   AND (@IncludeDeleted_Indicator = 'Y' OR [Deleted_Date] IS NULL)
	   AND (@BasePath_Text IS NULL OR CHARINDEX(LOWER(@BasePath_Text), [AssetItem_Lower_Path]) > 0)
	   AND ([AssetItem_Lower_Name] LIKE ('%' + LOWER(WORD.[Value_Text]) + '%') COLLATE Latin1_General_CS_AS)
    GROUP BY [AssetItem_Id]

	SELECT AI.* 
	  FROM [AssetItems_Paths] AI JOIN #Results ON AI.[AssetItem_Id] = #Results.[AssetItem_Id]
	ORDER BY [Word_Count] DESC, COALESCE([Name_Index],1000)

END
GO

GRANT EXECUTE ON [Assets_SearchItems] TO [ProGetUser_Role]