EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ClusterNodes_CreateOrUpdate',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ClusterNode_Id',
    /* Description_Text        */ 'Creates or updates a node in the cluster.'
GO

IF OBJECT_ID('[ClusterNodes_CreateOrUpdate]') IS NOT NULL DROP PROCEDURE [ClusterNodes_CreateOrUpdate]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ClusterNodes_CreateOrUpdate]
(
	@Node_Name NVARCHAR(100),
	@NodeType_Code CHAR(1),
	@Node_Configuration XML,
	@ClusterNode_Id INT = NULL OUT
)
AS
BEGIN
SET NOCOUNT ON

BEGIN TRY

	BEGIN TRANSACTION

	DECLARE @Now DATETIME
	SET @Now = GETUTCDATE()

	DECLARE @NodeIds TABLE ([Id] INT NOT NULL)

	UPDATE [ClusterNodes2] WITH (UPDLOCK, SERIALIZABLE) 
	   SET [LastUpdated_Date] = @Now,
		   [Node_Configuration] = @Node_Configuration,
		   [Live_Indicator] = 'Y'
	OUTPUT inserted.[ClusterNode_Id] INTO @NodeIds
	 WHERE [Node_Name] = @Node_Name
	   AND [NodeType_Code] = @NodeType_Code

	IF @@ROWCOUNT = 0 BEGIN

		INSERT INTO [ClusterNodes2] ([Node_Name], [NodeType_Code], [LastUpdated_Date], [Node_Configuration], [Primary_Indicator], [Live_Indicator])
		VALUES (@Node_Name, @NodeType_Code, @Now, @Node_Configuration, 'N', 'Y')

		SET @ClusterNode_Id = SCOPE_IDENTITY()

	END
	ELSE BEGIN

		SET @ClusterNode_Id = (SELECT [Id] FROM @NodeIds)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ClusterNodes_CreateOrUpdate] TO [ProGetUser_Role]
GO
