EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'FeedGroups_SetGroupMembership',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Marks a list of feeds as belonging to the specified feed group.'
GO

IF OBJECT_ID('[FeedGroups_SetGroupMembership]') IS NOT NULL DROP PROCEDURE [FeedGroups_SetGroupMembership]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [FeedGroups_SetGroupMembership]
(
	@FeedGroup_Id INT,
	@FeedIds_Csv VARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
    BEGIN TRANSACTION

	DECLARE @FeedIds_Table TABLE ([Feed_Id] INT NOT NULL)
	INSERT INTO @FeedIds_Table
	SELECT CAST([Value_Text] AS INT) FROM dbo.CsvToTable(@FeedIds_Csv, ',')

	UPDATE [Feeds]
	   SET [FeedGroup_Id] = NULL
	 WHERE [Feed_Id] NOT IN (SELECT [Feed_Id] FROM @FeedIds_Table)
	   AND [FeedGroup_Id] = @FeedGroup_Id

	UPDATE [Feeds]
	   SET [FeedGroup_Id] = @FeedGroup_Id
	 WHERE [Feed_Id] IN (SELECT [Feed_Id] FROM @FeedIds_Table)

    COMMIT
END TRY BEGIN CATCH
    IF XACT_STATE()<>0 ROLLBACK
    EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [FeedGroups_SetGroupMembership] TO [ProGetUser_Role]
